gapipy.models package
=====================

Submodules
----------

gapipy.models.add_on module
---------------------------

.. automodule:: gapipy.models.add_on
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.models.address module
----------------------------

.. automodule:: gapipy.models.address
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.models.arrival_flight_detail module
------------------------------------------

.. automodule:: gapipy.models.arrival_flight_detail
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.models.base module
-------------------------

.. automodule:: gapipy.models.base
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.models.departure_flight_detail module
--------------------------------------------

.. automodule:: gapipy.models.departure_flight_detail
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.models.departure_service_room module
-------------------------------------------

.. automodule:: gapipy.models.departure_service_room
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.models.document_info module
----------------------------------

.. automodule:: gapipy.models.document_info
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.models.incomplete_requirement module
-------------------------------------------

.. automodule:: gapipy.models.incomplete_requirement
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.models.international_ticket_number module
------------------------------------------------

.. automodule:: gapipy.models.international_ticket_number
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.models.price_band module
-------------------------------

.. automodule:: gapipy.models.price_band
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.models.room module
-------------------------

.. automodule:: gapipy.models.room
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.models.traveller_height module
-------------------------------------

.. automodule:: gapipy.models.traveller_height
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: gapipy.models
    :members:
    :undoc-members:
    :show-inheritance:
